; Support file for SRE-FILTER HTTP server. 5/96
; This file is used when ALLOW_ACCESS is binding:
;   ALLOW_ACCESS="INHOUSE" and the requester does not have INHOUSE privileges
;   ALLOW_ACCESS="NO" and requester is not a superuser
;
; SRE-FILTER will attempt to (exact or wildcard) match the current
; request string with one of these entries.
; If a match is found, SRE-FILTER will determine if access is allowed.
;
; If no match is found, then (assuming ALLOW_ACCESS is binding) access is
; denied.  In other words,
;
;      SRE-FILTER NEVER ADDS ENTRIES TO THIS FILE -- YOU MUST ADD THEM YOURSELF
;
; (but the * wildcard character can be used as a shortcut!)
;
; Each entry should have the form: NAME  priv_list , ss_options
;   The NAME  should be a possible URL 
;       (to be compared against the request string)
;       It may indicate a file, or a server side action.
;   The priv_list is optional,
;      If priv_list is present, only users with a privilege that appear in this
;      priv_list are allowed to access this action.
;      Or, you can set privlist = *, or privlist= YES ,
;          which means everyone has access
;         (it's the same thing as not having a user list!)
;      Or, you set privlist=NO, which means no one (except SUPERUERS) has access
;   The ss_options are optional (there MUST be comma seperating the privlist
;                                and the ss_options)
;      ss_options  can contain NO_SSI and/or NO_SSP (seperated by a space).  
;      NO_SSI means "no server side include allowed for this URL (or a "path" of URLs, if a
;      * appears).  Similarly, NO_SSP means "no server side processing allowed for this URL".
;      Note that these are only used if the SSI_ALLOW (or SSP_ALLOW) variable equals CHECK.
;
; A note on wildcard  matching:
;     The rule is:
;       1) If a * appears in the NAME, then SRE-FILTER will treat the *
;          as a (0 to infinite) length wildcard.  Thus, the
;          "request string" need only match the non-wildcarded component of NAME
;       2) If there are more then one possible matches, the rule is:
;           a) The first EXACT match is used.
;            b) If no exact, but several wildcard matches, the first wildcard match
;               is used.
;            c) In other words, exact matches always take precedence over
;               wildcard matches
;
;        Examples: /BILL/DOG.HTM will match /BILL/DOG.HTM
;                  /JOE/*  will match /JOE/FOO.HTM
;                  /JOAN/SRCH.HTM?*  will match /JOAN/SRCH.HTM?search+me
;                  /JOAN/SRCH.HTM?*  will NOT match /JOAN/SRCH.HTM
;                       (/JOAN/SRCH.HTM* will match BOTH these examples)
;                  /PETS/*INDEX.HTM will match
;                       /PETS/INDEX.HTM, /PETS/CAT/INDEX.HTM and
;                       /PETS/PUPPY/LAB/INDEX.HTM
;                    but will NOT match
;                       /PETS/CAT/PUREBRED.HTM
;
; Notes on / and \ :  They are treated the same (all / are converted to \)
;                       A Leading \ (or /) is stripped.
;
; - - - - - - - -
; The following entries are examples, and can be deleted if desired.
;
; Only superusers have access to the SYSTEM subdirectory
SYSTEM\*   NO
; only inhouse and superusers have access to the PRIVATE directory
PRIVATE\*  INHOUSE
; everyone has access to the PUBLIC\ directory
PUBLIC\*  *
; this wildcards all requests for getafile.  Add a privilege list if you 
; want to limit it's use (or, set the NO_GETAFILE_CONTROL variable)
GETAFILE*
; These wildcard the  message box facilitiy.
; Add a privilege list if desired ..
;MESSAGE*
;!ASKMESS*
; This controls access to the SECRET2 message box
;!VIEWMESS?messbox=secret2*  INHOUSE
; all other message boxes are open to everyone with VIEWMESS privileges.
;!VIEWMESS*
;
; This gives URLS to documents in the GUEST subdirectory (or virtual directory)
;  a limited purview (they can't include information,
; and server side processing programs located in them won't be run)
GUEST/*  * , NO_SSI NO_SSP
;
; and this last one means "for all other files, everyone has access" 
; (it's a catchall) -- change the second * to whatever privilege list 
; you want (i.e.; NO, to disallow all access, though NO is the default
; so it's unnecessary to include such an entry)
* *
